import debounce from "lodash.debounce";
import throttle from "lodash.throttle";
import * as React from "react";
var setRefreshRate = function (cb, refreshOptions) {
    var _a = refreshOptions || {}, mode = _a.mode, _b = _a.rate, rate = _b === void 0 ? 250 : _b, leading = _a.leading, trailing = _a.trailing;
    switch (mode) {
        case "debounce": {
            var lodashOptions = {
                leading: leading != null ? leading : false,
                trailing: trailing != null ? trailing : true
            };
            // eslint-disable-next-line @typescript-eslint/no-unsafe-call
            return debounce(cb, rate, lodashOptions);
        }
        case "throttle": {
            var lodashOptions = {
                leading: leading != null ? leading : true,
                trailing: trailing != null ? trailing : true
            };
            // eslint-disable-next-line @typescript-eslint/no-unsafe-call
            return throttle(cb, rate, lodashOptions);
        }
        default:
            return cb;
    }
};
var useResizeSensor = function (refreshOptions) {
    var _a = React.useState({ width: 0, height: 0 }), size = _a[0], setSize = _a[1];
    var handleOnResize = React.useCallback(function (entries) {
        entries.forEach(function (entry) {
            var _a = entry.contentRect, width = _a.width, height = _a.height;
            setSize(function (prevSize) {
                if (prevSize.width === width && prevSize.height === height)
                    return prevSize;
                return { width: width, height: height };
            });
        });
    }, []);
    var resizeCallback = React.useMemo(function () { return setRefreshRate(handleOnResize, refreshOptions); }, [handleOnResize, refreshOptions]);
    var registerCleanupRef = React.useRef(null);
    var registerNode = React.useCallback(function (node) {
        if (registerCleanupRef.current !== null) {
            registerCleanupRef.current();
            registerCleanupRef.current = null;
        }
        if (node != null) {
            var observer_1 = new ResizeObserver(resizeCallback);
            observer_1.observe(node);
            registerCleanupRef.current = function () {
                observer_1.disconnect();
                if (resizeCallback.cancel)
                    resizeCallback.cancel();
            };
        }
    }, [resizeCallback]);
    return { width: size.width, height: size.height, registerNode: registerNode };
};
export default useResizeSensor;
